"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var classnames_1 = require("classnames");
var List_1 = require("@material-ui/core/List");
var styles_1 = require("@material-ui/styles");
var Drawer_1 = require("@material-ui/core/Drawer");
var LystDrawerItem_1 = require("../LystDrawerItem");
var LystDrawerSubItem_1 = require("../LystDrawerSubItem");
var LystCollapsible_1 = require("../LystCollapsible");
var LystDropDown_1 = require("../LystDropDown");
var LystDropDownItem_1 = require("../LystDropDownItem");
var hooks_1 = require("../../customs/hooks");
// Default DrawerStyles for collapse/expand animation
// keys for Inline styles must be camelcase
// check allowed types for each key by hovering over or (cmd + 'click') on specific key
var drawerStyles = styles_1.makeStyles(function (theme) {
    var _a;
    return ({
        root: {
            display: 'flex',
            height: '100%',
            overflow: 'auto',
            overflowX: 'hidden'
        },
        drawerOpen: {
            width: 235,
            transition: theme.transitions.create('width', {
                easing: theme.transitions.easing.sharp,
                duration: theme.transitions.duration.enteringScreen
            })
        },
        drawerClose: (_a = {
                transition: theme.transitions.create('width', {
                    easing: theme.transitions.easing.sharp,
                    duration: theme.transitions.duration.leavingScreen
                }),
                overflowX: 'hidden',
                width: theme.spacing.unit * 6 + 1
            },
            _a[theme.breakpoints.up('sm')] = {
                width: theme.spacing.unit * 7.5 + 1
            },
            _a)
    });
});
var LystDrawer = function (_a) {
    var _b;
    var position = _a.position, open = _a.open, menuItems = _a.menuItems, styles = _a.styles;
    var drawerClasses = drawerStyles();
    var _c = hooks_1.drawerHook(open), selectedIndex = _c.selectedIndex, anchorElement = _c.anchorElement, handleListItemClick = _c.handleListItemClick, handleClose = _c.handleClose;
    return (React.createElement("aside", { className: drawerClasses.root },
        React.createElement(Drawer_1.default, { anchor: position, variant: 'permanent', classes: {
                paper: classnames_1.default((_b = {},
                    _b[drawerClasses.drawerOpen] = open,
                    _b[drawerClasses.drawerClose] = !open,
                    _b))
            }, open: open },
            React.createElement(List_1.default, { disablePadding: true }, menuItems.map(function (rootItem, index, array) { return (
            // mapping through menuItems Array
            // style divider for all except last item
            // Pass array index and the state selectedIndex to only expand subItems that belong to the event(click) target
            React.createElement("div", { key: "rootItem-" + index },
                React.createElement(LystDrawerItem_1.default, { placement: position, tooltip: !open, tabIndex: index, styles: styles.drawerItem, name: rootItem.name, handleClick: handleListItemClick, Icon: rootItem.icon, divider: array.length - 1 !== index }),
                React.createElement(LystCollapsible_1.default, { open: open && index === selectedIndex }, rootItem.subItems.map(function (subItem, index) { return (
                // Pass name and path to the navlink component
                React.createElement(LystDrawerSubItem_1.default, { key: "subItem-" + index, content: subItem.name, path: subItem.path, styles: styles.drawerSubItem })); })),
                !open && index === selectedIndex && (
                // Only Render LystDropDown when Drawer is closed and the item selected matches corresponding index in menuItems array
                // anchorElement is the target node to enable position dropDown near the element
                React.createElement(LystDropDown_1.default, { position: position, handleClose: handleClose, anchorElement: anchorElement, styles: styles.dropDown },
                    React.createElement(LystDropDownItem_1.default, { content: rootItem.name }),
                    rootItem.subItems.map(function (subItem, index) { return (React.createElement(LystDropDownItem_1.default, { key: "dropDown-" + index, component: subItem.component, content: subItem.name })); }))))); })))));
};
LystDrawer.defaultProps = {
    styles: {
        drawerSubItem: null,
        drawerItem: null,
        dropDown: null
    }
};
exports.default = LystDrawer;
//# sourceMappingURL=LystDrawer.js.map