import * as React from 'react';
import Button from '@material-ui/core/Button';
import Tooltip from '@material-ui/core/Tooltip';
import generateStyles from '../../customs/styleFactory';
import classNames from 'classnames';

interface Props {
  title: string;
  tooltip: boolean;
  tooltipMsg: string;
  styles?: any;
  tooltipPlacement?:
    | 'bottom-end'
    | 'bottom-start'
    | 'bottom'
    | 'left-end'
    | 'left-start'
    | 'left'
    | 'right-end'
    | 'right-start'
    | 'right'
    | 'top-end'
    | 'top-start'
    | 'top';
  variant:
    | 'text'
    | 'flat'
    | 'outlined'
    | 'contained'
    | 'raised'
    | 'fab'
    | 'extendedFab';
  color: 'inherit' | 'primary' | 'secondary' | 'default' | undefined;
  classes?: any;
  type: 'button' | 'submit';
}

const LystButton: React.FunctionComponent<Props> = ({
  title,
  type,
  tooltip,
  tooltipPlacement,
  variant,
  color,
  styles,
  tooltipMsg
}) => {
  let classes: any;
  styles ? (classes = generateStyles(styles)()) : null;

  const lystButton = (
    <Button
      type={type}
      variant={variant}
      color={color}
      classes={{
        root: classNames({
          [classes.button]: classes.button
        })
      }}
    >
      {title}
    </Button>
  );
  return tooltip ? (
    <Tooltip placement={tooltipPlacement} title={tooltipMsg}>
      {lystButton}
    </Tooltip>
  ) : (
    lystButton
  );
};

LystButton.defaultProps = {
  styles: { button: null }
};

export default LystButton;
