import * as React from 'react';
import ListItem from '@material-ui/core/ListItem';
import Tooltip from '@material-ui/core/Tooltip';
import ListItemIcon from '@material-ui/core/ListItemIcon';
import ListItemText from '@material-ui/core/ListItemText';

const LystDrawerItem: React.FunctionComponent<{
  tooltip: boolean;
  styles?: any;
  placement:
    | 'bottom-end'
    | 'bottom-start'
    | 'bottom'
    | 'left-end'
    | 'left-start'
    | 'left'
    | 'right-end'
    | 'right-start'
    | 'right'
    | 'top-end'
    | 'top-start'
    | 'top';
  tabIndex: number;
  divider: boolean;
  name: string;
  handleClick: Function;
  Icon: any;
}> = ({
  styles,
  name,
  Icon,
  divider,
  placement,
  tooltip,
  handleClick,
  tabIndex
}) => {
  // store listitem jsx for readable conditional rendering
  const listItem = (
    <ListItem
      key={`list-item-${tabIndex}`}
      divider={divider}
      onClick={event => handleClick(event)}
      tabIndex={tabIndex}
      button={true}
      id={name}
      classes={{
        root: styles
      }}
    >
      <ListItemIcon>
        <Icon />
      </ListItemIcon>
      <ListItemText primary={name} />
    </ListItem>
  );

  return tooltip ? (
    // Show a tooltip w/listItem only if drawer is closed
    <Tooltip placement={placement} title={name}>
      {listItem}
    </Tooltip>
  ) : (
    // else only render listItem
    listItem
  );
};

export default LystDrawerItem;
