import * as React from 'react';
import CircularProgress from '@material-ui/core/CircularProgress';
import { makeStyles } from '@material-ui/styles';

interface ILystLoadingProps {
  color?: 'primary' | 'secondary' | 'inherit';
  variant?: 'determinate' | 'indeterminate' | 'static';
  classes?: any;
  size?: number | string;
  thickness?: number;
}

const LystLoading: React.FunctionComponent<ILystLoadingProps> = ({
  color,
  classes,
  variant,
  thickness,
  size
}) => (
  <div
    style={{
      position: 'absolute',
      height: '100vh',
      width: '100vw',
      opacity: 0.8,
      zIndex: 1500
    }}
  >
    <div
      className={
        classes
          ? classes.rootContainer
          : makeStyles((theme: any) => {
              return {
                rootContainer: {
                  background: theme.palette.secondary.contrastText,
                  height: '100%',
                  width: '100%',
                  backgroundBlendMode: 'multiply',
                  position: 'relative'
                }
              };
            })().rootContainer
      }
    >
      <CircularProgress
        thickness={thickness ? thickness : 3.6}
        size={size ? size : 100}
        variant={variant ? variant : 'indeterminate'}
        color={color ? color : 'primary'}
        style={{
          position: 'absolute',
          left: 0,
          right: 0,
          top: 0,
          bottom: 0,
          margin: 'auto'
        }}
      />
    </div>
  </div>
);

export default LystLoading;
