import * as React from 'react';
import TextField from '@material-ui/core/TextField';
import InputAdornment from '@material-ui/core/InputAdornment';
import IconButton from '@material-ui/core/IconButton';
import VisibilityOff from '@material-ui/icons/VisibilityOff';
import Visibility from '@material-ui/icons/Visibility';
import classNames from 'classnames';
import AccountCircle from '@material-ui/icons/AccountCircle';
import { inputHooks } from '../../customs/hooks';
import generateStyles from '../../customs/styleFactory';

const LystLoginField: React.FunctionComponent<{
  required: boolean;
  variant: any;
  styles?: any;
  type: 'password' | 'username';
  inputVal: string;
  handleChange: Function;
}> = ({ styles, required, variant, type, inputVal, handleChange }) => {
  let classes: any;
  styles ? (classes = generateStyles(styles)()) : (classes = styles);
  const { handlePasswordIconClick, showPassword } = inputHooks();
  let setIcon = () => {
    switch (type) {
      case 'password':
        return showPassword ? <VisibilityOff /> : <Visibility />;
      default:
        return <AccountCircle />;
    }
  };

  return (
    <TextField
      margin={'normal'}
      variant={variant}
      classes={{
        root: classNames({
          [classes.input]: classes.input
        })
      }}
      required={required}
      type={type === 'username' ? 'text' : showPassword ? 'text' : 'password'}
      name={type}
      label={type.charAt(0).toUpperCase() + type.slice(1)}
      value={inputVal}
      onChange={handleChange(type)}
      InputProps={{
        endAdornment: (
          <InputAdornment position="end">
            <IconButton
              aria-label="Toggle password visibility"
              onClick={type === 'password' ? handlePasswordIconClick : () => {}}
              classes={{
                root: classNames({
                  [classes.icon]: classes.icon
                })
              }}
            >
              {setIcon()}
            </IconButton>
          </InputAdornment>
        )
      }}
    />
  );
};

LystLoginField.defaultProps = {
  styles: { input: null, icon: null }
};

export default LystLoginField;
