import * as React from 'react';
import LystLoginField from '../LystLoginField';
import LystButton from '../LystButton';
import CssBaseline from '@material-ui/core/CssBaseline';
import { loginFormHooks } from '../../customs/hooks';

const LystLoginForm: React.FunctionComponent<{
  handleSubmit: Function;
  fieldStyles?: any;
  buttonStyles?: any;
}> = ({ handleSubmit, fieldStyles, buttonStyles }) => {
  const { password, username, handleChange } = loginFormHooks();
  return (
    <>
      <CssBaseline />
      <form
        style={{
          height: '100%',
          width: '100%',
          display: 'flex',
          flexDirection: 'column',
          alignItems: 'center'
        }}
        onSubmit={event => handleSubmit(event)}
      >
        <LystLoginField
          type="username"
          variant={'outlined'}
          styles={fieldStyles}
          required={true}
          inputVal={username}
          handleChange={handleChange}
        />
        <LystLoginField
          type="password"
          variant={'outlined'}
          styles={fieldStyles}
          required={true}
          inputVal={password}
          handleChange={handleChange}
        />
        <LystButton
          type={'submit'}
          title={'Login ➡'}
          tooltip={!username || !password ? true : false}
          tooltipMsg={
            !username
              ? 'Missing Username!'
              : !password
              ? 'Missing Password'
              : 'Login ➡'
          }
          variant={'outlined'}
          styles={buttonStyles}
          color={'primary'}
        />
      </form>
    </>
  );
};
export default LystLoginForm;
