import * as React from 'react';
import List from '@material-ui/core/List';
import ListItem from '@material-ui/core/ListItem';
import ListItemText from '@material-ui/core/ListItemText';
import classNames from 'classnames';
import generateStyles from '../../customs/styleFactory';
import { ListItemTextStyles, ListStyles } from '../../styles';
// import { HeaderMenu } from '../../types';
import LystDropDown from '../LystDropDown';
import LystDropDownItem from '../LystDropDownItem';

import { drawerHook } from '../../customs/hooks';

const LystNavBar: React.FunctionComponent<{
  items: any[];
  disablePadding: boolean;
  styles?: any;
}> = ({ styles, items, disablePadding }) => {
  const {
    selectedIndex,
    anchorElement,
    handleListItemClick,
    handleClose
  } = drawerHook(false);
  let customStyles: any;
  const listItemTextClasses = ListItemTextStyles();
  const listClasses = ListStyles();
  styles
    ? (customStyles = generateStyles(styles)())
    : (customStyles = { list: null, listItem: null, listItemText: null });
  return (
    <List
      classes={{
        root: classNames({
          [listClasses.row]: disablePadding,
          [customStyles.list]: customStyles.list
        })
      }}
      disablePadding={disablePadding}
    >
      {items.map((item, index: number) => {
        return (
          <div key={`navbar-${index}`}>
            <ListItem
              tabIndex={index}
              classes={{
                root: classNames({
                  [customStyles.listItem]: customStyles.listItem
                })
              }}
              key={`nav-item-${index}`}
              onClick={handleListItemClick}
            >
              <ListItemText
                classes={{
                  root: classNames({
                    [listItemTextClasses.disablePadding]: disablePadding,
                    [customStyles.listItemText]: customStyles.listItemText
                  })
                }}
                primary={item.name}
              />
            </ListItem>
            {index === selectedIndex && item.subItems && (
              <LystDropDown
                handleClose={handleClose}
                anchorElement={anchorElement}
                position={'top'}
              >
                <LystDropDownItem content={item.name} />

                {item.subItems.map((subItem: any, index: number) => {
                  return (
                    <LystDropDownItem
                      content={subItem.name}
                      component={subItem.component}
                    />
                  );
                })}
              </LystDropDown>
            )}
          </div>
        );
      })}
    </List>
  );
};

export default LystNavBar;
