import { useState } from 'react';

export const drawerHook = (open: boolean) => {
  const [selectedIndex, setIndex] = useState<number>(NaN);
  const [anchorElement, setAnchorElement] = useState<React.ReactNode | null>(
    null
  );

  const handleListItemClick = (event: React.MouseEvent<HTMLElement>) => {
    const { currentTarget } = event;
    const { tabIndex } = currentTarget;
    !open
      ? (() => {
          setIndex(tabIndex);
          setAnchorElement(currentTarget);
        })()
      : tabIndex === selectedIndex
      ? setIndex(NaN)
      : setIndex(tabIndex);
  };

  const handleClose = () => {
    setAnchorElement(null);
  };

  return {
    selectedIndex,
    anchorElement,
    handleListItemClick,
    handleClose
  };
};

export const dropDownHook = () => {
  const [anchorElement, setAnchorElement] = useState<React.ReactNode | null>(
    null
  );
  const handleIconClick = (event: React.MouseEvent<HTMLElement>) => {
    setAnchorElement(event.currentTarget);
  };

  const handleClose = () => {
    setAnchorElement(null);
  };

  return {
    anchorElement,
    handleIconClick,
    handleClose
  };
};

export const loginFormHooks = () => {
  const [password, updatePassword] = useState<string>('');
  const [username, updateUsername] = useState<string>('');

  const handleChange = (prop: 'password' | 'username') => (
    event: React.ChangeEvent<HTMLInputElement>
  ) => {
    const { value, name } = event.target;
    name === 'username' ? updateUsername(value) : updatePassword(value);
  };

  return {
    password,
    username,
    handleChange
  };
};

export const inputHooks = () => {
  const [showPassword, setShowPassword] = useState(false);

  const handlePasswordIconClick = () => {
    setShowPassword(!showPassword);
  };

  return {
    handlePasswordIconClick,
    showPassword
  };
};
