import * as React from 'react';
import PersonOutline from '@material-ui/icons/PersonOutline';
import PeopleOutlineTwoTone from '@material-ui/icons/PeopleOutlineTwoTone';

import SearchTwoTone from '@material-ui/icons/SearchTwoTone';
import ViewModuleTwoTone from '@material-ui/icons/ViewModuleTwoTone';
import InsertChartOutlined from '@material-ui/icons/InsertChartOutlined';
import LocalHospital from '@material-ui/icons/LocalHospital';
import LocalPharmacyTwoTone from '@material-ui/icons/LocalPharmacyTwoTone';
import ReceiptOutlined from '@material-ui/icons/ReceiptOutlined';
import AssignmentInd from '@material-ui/icons/AssignmentInd';
import { NavLink } from 'react-router-dom';

const icons = {
  currentResident: PersonOutline,
  charting: InsertChartOutlined,
  marTar: LocalHospital,
  orders: ReceiptOutlined,
  pharmacyRequest: LocalPharmacyTwoTone,
  careTasks: AssignmentInd,
  residentSearch: SearchTwoTone,
  ppoContingencyBulk: ViewModuleTwoTone,
  medTaskManagement: PeopleOutlineTwoTone
};

const rootPaths = {
  pharmacyRequest: 'pharmacy-request',
  currentResident: 'current-resident',
  charting: 'charting',
  marTar: 'mar-tar',
  orders: 'orders',
  careTasks: 'care-tasks'
};

export const generateDrawerRoutes = (rootName: string, subItems: string[]) => {
  return {
    name: rootName,
    icon: icons[rootName],
    subItems: subItems.map((itemName: any, index: number) => {
      return {
        name: itemName,
        path: `/${rootPaths[rootName]}/${itemName}`,
        component: (props: any) => {
          const { innerRef, ...otherProps } = props;
          return (
            <NavLink
              key={`navlink-${index}`}
              {...otherProps}
              to={`/${rootName}/${itemName}`}
            />
          );
        }
      };
    })
  };
};

export const generateNavRoutes = (rootName: string, subItems: string[]) => {
  return {
    name: rootName,
    subItems: subItems.length
      ? subItems.map((itemName: any, index: number) => {
          return {
            name: itemName,
            path: `/${rootPaths[rootName]}/${itemName}`,
            component: (props: any) => {
              const { innerRef, ...otherProps } = props;
              return (
                <NavLink
                  key={`navlink-${index}`}
                  {...otherProps}
                  to={`/${rootName}/${itemName}`}
                />
              );
            }
          };
        })
      : null
  };
};
