import * as React from 'react';
import { BrowserRouter as Router } from 'react-router-dom';
import LystHeader from '../components/LystHeader';
import Grid from '@material-ui/core/Grid';
import LystAvatar from '../components/LystAvatar';
import LystDropDown from '../components/LystDropDown';
import LystDropDownItem from '../components/LystDropDownItem';
import LystRadioGroup from '../components/LystRadioGroup';
import LystDrawer from '../components/LystDrawer';
import LystNavBar from '../components/LystNavBar';
import { dropDownHook } from '../customs/hooks';
import { patientMenu, headerMenu } from '../assets/routes';
import generateStyles from 'customs/styleFactory';

const navbarStyles = {
  list: {
    display: 'flex'
  },
  listItemText: {
    '& span': {
      color: 'white'
    }
  }
};

const Landing = () => {
  const [open, setOpen] = React.useState(false);

  const { anchorElement, handleIconClick, handleClose } = dropDownHook();

  const toggleMenu = () => {
    setOpen(!open);
  };
  const handleRadioChange = (event: React.MouseEvent<HTMLElement>) => {
    event.stopPropagation();
  };

  const drawerStyles = generateStyles({
    drawerItem: {
      '&:focus': {
        '& svg': {
          fill: 'white'
        }
      },
      '&:hover': {
        '& svg': {
          fill: 'white'
        },
        '& span': {
          color: 'white'
        }
      }
    },
    drawerSubItem: {
      '&:hover span': {
        color: 'white'
      }
    },
    dropDown: {
      '& a': {
        padding: '.8rem 2rem'
      },
      '& a:hover': {
        color: 'white'
      }
    }
  })();

  return (
    <Router>
      <Grid direction="column" container>
        <LystHeader open={open} handleMenuClick={toggleMenu}>
          <LystNavBar
            styles={navbarStyles}
            disablePadding={true}
            items={headerMenu}
          />
          <LystAvatar handleClick={handleIconClick} initials={'OM'} />
          {anchorElement && (
            <LystDropDown
              handleClose={handleClose}
              anchorElement={anchorElement}
              styles={'top'}
            >
              <LystDropDownItem
                component={(props: any) => (
                  <LystRadioGroup
                    {...props}
                    classes={'row'}
                    styles={{ radio: { padding: '.5rem' } }}
                    items={['orange', 'green', 'blue']}
                    handleChange={handleRadioChange}
                    formLabel={'theme'}
                  />
                )}
              />
            </LystDropDown>
          )}
        </LystHeader>
        <Grid>
          <LystDrawer
            styles={drawerStyles}
            menuItems={patientMenu}
            open={open}
            position={'left'}
          />
        </Grid>
      </Grid>
    </Router>
  );
};

export default Landing;
