import React from 'react';
import LystButton from '../components/LystButton';
import { storiesOf } from '@storybook/react';
import LystThemeProvider from '../components/LystThemeProvider';
import { text, boolean, select } from '@storybook/addon-knobs/react';

const colorOptions = {
  inherit: 'inherit',
  primary: 'primary',
  secondary: 'secondary',
  default: 'default',
  undefined: undefined
};

const tooltipPlacementOptions = {
  bottomEnd: 'bottom-end',
  bottomStart: 'bottom-start',
  bottom: 'bottom',
  leftEnd: 'left-end',
  leftStart: 'left-start',
  left: 'left',
  rightEnd: 'right-end',
  rightStart: 'right-start',
  right: 'right',
  topEnd: 'top-end',
  topStart: 'top-start',
  top: 'top'
};

storiesOf('Button', module)
  .addWithJSX('Basic Button', () => (
    <LystButton
      title={text('Title', 'Paul', 'title')}
      type={'button'}
      tooltip={boolean('Tooltip', true, 'tooltip?')}
      tooltipPlacement={select(
        'Tooltip Position',
        tooltipPlacementOptions,
        'bottom',
        'tooltip placement'
      )}
      variant={'outlined'}
      color={select('Color Options', colorOptions, 'inherit', 'color')}
    />
  ))
  .addWithJSX('Themed Button', () => (
    <>
      <LystThemeProvider theme={'orange'}>
        <LystButton
          type={'button'}
          title={text('Title', 'Paul', 'title')}
          tooltip={boolean('Tooltip', true, 'tooltip?')}
          tooltipPlacement={select(
            'Tooltip Position',
            tooltipPlacementOptions,
            'bottom',
            'tooltip placement'
          )}
          variant={'outlined'}
          color={select('Color Options', colorOptions, 'primary', 'color')}
        />
      </LystThemeProvider>
      <LystThemeProvider theme={'blue'}>
        <LystButton
          type={'button'}
          title={text('Title', 'Paul', 'title')}
          tooltip={boolean('Tooltip', true, 'tooltip?')}
          tooltipPlacement={select(
            'Tooltip Position',
            tooltipPlacementOptions,
            'bottom',
            'tooltip placement'
          )}
          variant={'outlined'}
          color={select('Color Options', colorOptions, 'primary', 'color')}
        />
      </LystThemeProvider>
      <LystThemeProvider theme={'green'}>
        <LystButton
          title={text('Title', 'Paul', 'title')}
          tooltip={boolean('Tooltip', true, 'tooltip?')}
          tooltipPlacement={select(
            'Tooltip Position',
            tooltipPlacementOptions,
            'bottom',
            'tooltip placement'
          )}
          variant={'outlined'}
          color={select('Color Options', colorOptions, 'primary', 'color')}
        />
      </LystThemeProvider>
    </>
  ));
